@@ -119,6 +119,19 @@ CoordMap <- ggproto("CoordMap", Coord,
     out
   },
 
+  backtransform_range = function(panel_params) {
+    # range is stored in data coordinates and doesn't have to be back-transformed
+    list(x = panel_params$x.range, y = panel_params$y.range)
+  },
+
+  range = function(panel_params) {
+    # Range in projected coordinates:
+    #   list(x = panel_params$x.proj, y = panel_params$y.proj)
+    # However, coord_map() does never really work with transformed coordinates,
+    # so return unprojected data coordinates here
+    list(x = panel_params$x.range, y = panel_params$y.range)
+  },
+
   distance = function(x, y, panel_params) {
     max_dist <- dist_central_angle(panel_params$x.range, panel_params$y.range)
     dist_central_angle(x, y) / max_dist
