@@ -1,9 +1,12 @@
-#' Set guides for each scale.
+#' Set guides for each scale
 #'
-#' Guides for each scale can be set in call of \code{scale_*} with argument
-#' \code{guide}, or in \code{guides}.
+#' Guides for each scale can be set scale-by-scale with the `guide`
+#' argument, or en masse with `guides()`.
 #'
-#' @param ... List of scale guide pairs
+#' @param ... List of scale name-guide pairs.  The guide can either
+#'   be a string (i.e. "colorbar" or "legend"), or a call to a guide function
+#'   (i.e. [guide_colourbar()] or [guide_legend()])
+#'   specifying additional arguments.
 #' @return A list containing the mapping between scale and guide.
 #' @export
 #' @family guides
@@ -45,8 +48,6 @@
 #'
 #' # position of guides
 #'
-#' p + theme(legend.position = "bottom", legend.box = "horizontal")
-#'
 #' # Set order for multiple guides
 #' ggplot(mpg, aes(displ, cty)) +
 #'   geom_point(aes(size = hwy, colour = cyl, shape = drv)) +
@@ -93,32 +94,24 @@ update_guides <- function(p, guides) {
 #      arrange all ggrobs
 
 build_guides <- function(scales, layers, default_mapping, position, theme, guides, labels) {
-
-  # set themes w.r.t. guides
-  # should these theme$legend.XXX be renamed to theme$guide.XXX ?
-
-  # by default, guide boxes are vertically aligned
-  theme$legend.box <- theme$legend.box %||% "vertical"
-
-  # size of key (also used for bar in colorbar guide)
   theme$legend.key.width <- theme$legend.key.width %||% theme$legend.key.size
   theme$legend.key.height <- theme$legend.key.height %||% theme$legend.key.size
 
-  # by default, direction of each guide depends on the position of the guide.
-  theme$legend.direction <-
-    theme$legend.direction %||%
-    if (length(position) == 1 && position %in% c("top", "bottom", "left", "right"))
-      switch(position[1], top = , bottom = "horizontal", left = , right = "vertical")
-    else
-      "vertical"
-
-  # justification of legend boxes
-  theme$legend.box.just <-
-    theme$legend.box.just %||%
-    if (length(position) == 1 && position %in% c("top", "bottom", "left", "right"))
-      switch(position, bottom = , top = c("center", "top"), left = , right = c("left", "top"))
-    else
-      c("center", "center")
+  # Layout of legends depends on their overall location
+  position <- legend_position(position)
+  if (position == "inside") {
+    theme$legend.box <- theme$legend.box %||% "vertical"
+    theme$legend.direction <- theme$legend.direction %||% "vertical"
+    theme$legend.box.just <- theme$legend.box.just %||% c("center", "center")
+  } else if (position == "vertical") {
+    theme$legend.box <- theme$legend.box %||% "vertical"
+    theme$legend.direction <- theme$legend.direction %||% "vertical"
+    theme$legend.box.just <- theme$legend.box.just %||% c("left", "top")
+  } else if (position == "horizontal") {
+    theme$legend.box <- theme$legend.box %||% "horizontal"
+    theme$legend.direction <- theme$legend.direction %||% "horizontal"
+    theme$legend.box.just <- theme$legend.box.just %||% c("center", "top")
+  }
 
   # scales -> data for guides
   gdefs <- guides_train(scales = scales, theme = theme, guides = guides, labels = labels)
@@ -140,6 +133,19 @@ build_guides <- function(scales, layers, default_mapping, position, theme, guide
   grobs
 }
 
+# Simplify legend position to one of horizontal/vertical/inside
+legend_position <- function(position) {
+  if (length(position) == 1) {
+    if (position %in% c("top", "bottom")) {
+      "horizontal"
+    } else {
+      "vertical"
+    }
+  } else {
+    "inside"
+  }
+}
+
 # validate guide object
 validate_guide <- function(guide) {
   # if guide is specified by character, then find the corresponding guide
@@ -156,37 +162,38 @@ guides_train <- function(scales, theme, guides, labels) {
 
   gdefs <- list()
   for (scale in scales$scales) {
+    for (output in scale$aesthetics) {
 
-    # guides(XXX) is stored in guides[[XXX]],
-    # which is prior to scale_ZZZ(guide=XXX)
-    # guide is determined in order of:
-    #   + guides(XXX) > + scale_ZZZ(guide=XXX) > default(i.e., legend)
-    output <- scale$aesthetics[1]
-    guide <- guides[[output]] %||% scale$guide
+      # guides(XXX) is stored in guides[[XXX]],
+      # which is prior to scale_ZZZ(guide=XXX)
+      # guide is determined in order of:
+      #   + guides(XXX) > + scale_ZZZ(guide=XXX) > default(i.e., legend)
+      guide <- guides[[output]] %||% scale$guide
 
-    # this should be changed to testing guide == "none"
-    # scale$legend is backward compatibility
-    # if guides(XXX=FALSE), then scale_ZZZ(guides=XXX) is discarded.
-    if (guide == "none" || (is.logical(guide) && !guide)) next
+      # this should be changed to testing guide == "none"
+      # scale$legend is backward compatibility
+      # if guides(XXX=FALSE), then scale_ZZZ(guides=XXX) is discarded.
+      if (identical(guide, "none") || isFALSE(guide)) next
 
-    # check the validity of guide.
-    # if guide is character, then find the guide object
-    guide <- validate_guide(guide)
+      # check the validity of guide.
+      # if guide is character, then find the guide object
+      guide <- validate_guide(guide)
 
-    # check the consistency of the guide and scale.
-    if (guide$available_aes != "any" && !scale$aesthetics %in% guide$available_aes)
-      stop("Guide '", guide$name, "' cannot be used for '", scale$aesthetics, "'.")
+      # check the consistency of the guide and scale.
+      if (!identical(guide$available_aes, "any") && !any(scale$aesthetics %in% guide$available_aes))
+        stop("Guide '", guide$name, "' cannot be used for '", scale$aesthetics, "'.")
 
-    guide$title <- guide$title %|W|% scale$name %|W|% labels[[output]]
+      guide$title <- scale$make_title(guide$title %|W|% scale$name %|W|% labels[[output]])
 
-    # direction of this grob
-    guide$direction <- guide$direction %||% theme$legend.direction
+      # direction of this grob
+      guide$direction <- guide$direction %||% theme$legend.direction
 
-    # each guide object trains scale within the object,
-    # so Guides (i.e., the container of guides) need not to know about them
-    guide <- guide_train(guide, scale)
+      # each guide object trains scale within the object,
+      # so Guides (i.e., the container of guides) need not to know about them
+      guide <- guide_train(guide, scale, output)
 
-    if (!is.null(guide)) gdefs[[length(gdefs) + 1]] <- guide
+      if (!is.null(guide)) gdefs[[length(gdefs) + 1]] <- guide
+    }
   }
   gdefs
 }
@@ -227,9 +234,9 @@ guides_gengrob <- function(gdefs, theme) {
 
 # build up all guide boxes into one guide-boxes.
 guides_build <- function(ggrobs, theme) {
-  theme$legend.margin <- theme$legend.margin %||% unit(0.5, "lines")
-  theme$legend.vmargin <- theme$legend.vmargin  %||% theme$legend.margin
-  theme$legend.hmargin <- theme$legend.hmargin  %||% theme$legend.margin
+  theme$legend.spacing <- theme$legend.spacing %||% unit(0.5, "lines")
+  theme$legend.spacing.y <- theme$legend.spacing.y  %||% theme$legend.spacing
+  theme$legend.spacing.x <- theme$legend.spacing.x  %||% theme$legend.spacing
 
   widths <- do.call("unit.c", lapply(ggrobs, function(g)sum(g$widths)))
   heights <- do.call("unit.c", lapply(ggrobs, function(g)sum(g$heights)))
@@ -241,7 +248,7 @@ guides_build <- function(ggrobs, theme) {
   yjust <- just[2]
 
   # setting that is different for vertical and horizontal guide-boxes.
-  if (theme$legend.box == "horizontal") {
+  if (identical(theme$legend.box, "horizontal")) {
     # Set justification for each legend
     for (i in seq_along(ggrobs)) {
       ggrobs[[i]] <- editGrob(ggrobs[[i]],
@@ -254,9 +261,9 @@ guides_build <- function(ggrobs, theme) {
       widths = widths, height = max(heights))
 
     # add space between the guide-boxes
-    guides <- gtable_add_col_space(guides, theme$legend.hmargin)
+    guides <- gtable_add_col_space(guides, theme$legend.spacing.x)
 
-  } else if (theme$legend.box == "vertical") {
+  } else { # theme$legend.box == "vertical"
     # Set justification for each legend
     for (i in seq_along(ggrobs)) {
       ggrobs[[i]] <- editGrob(ggrobs[[i]],
@@ -269,25 +276,61 @@ guides_build <- function(ggrobs, theme) {
       width = max(widths), heights = heights)
 
     # add space between the guide-boxes
-    guides <- gtable_add_row_space(guides, theme$legend.vmargin)
+    guides <- gtable_add_row_space(guides, theme$legend.spacing.y)
   }
 
-  # add margins around the guide-boxes.
-  guides <- gtable_add_cols(guides, theme$legend.hmargin, pos = 0)
-  guides <- gtable_add_cols(guides, theme$legend.hmargin, pos = ncol(guides))
-  guides <- gtable_add_rows(guides, theme$legend.vmargin, pos = 0)
-  guides <- gtable_add_rows(guides, theme$legend.vmargin, pos = nrow(guides))
+  # Add margins around the guide-boxes.
+  theme$legend.box.margin <- theme$legend.box.margin %||% margin()
+  guides <- gtable_add_cols(guides, theme$legend.box.margin[4], pos = 0)
+  guides <- gtable_add_cols(guides, theme$legend.box.margin[2], pos = ncol(guides))
+  guides <- gtable_add_rows(guides, theme$legend.box.margin[1], pos = 0)
+  guides <- gtable_add_rows(guides, theme$legend.box.margin[3], pos = nrow(guides))
 
+  # Add legend box background
+  background <- element_grob(theme$legend.box.background %||% element_blank())
+
+  guides <- gtable_add_grob(guides, background, t = 1, l = 1,
+    b = -1, r = -1, z = -Inf, clip = "off", name = "legend.box.background")
   guides$name <- "guide-box"
   guides
 }
 
-# S3 dispatches
+# Generics ----------------------------------------------------------------
 
-guide_train <- function(...) UseMethod("guide_train")
+#' S3 generics for guides.
+#'
+#' You will need to provide methods for these S3 generics if you want to
+#' create your own guide object. They are currently undocumented; use at
+#' your own risk!
+#'
+#' @param guide The guide object
+#' @keywords internal
+#' @name guide-exts
+NULL
 
-guide_merge <- function(...) UseMethod("guide_merge")
+#' @export
+#' @rdname guide-exts
+guide_train <- function(guide, scale, aesthetic = NULL) UseMethod("guide_train")
 
-guide_geom <- function(...) UseMethod("guide_geom")
+#' @export
+#' @rdname guide-exts
+guide_merge <- function(guide, new_guide) UseMethod("guide_merge")
 
-guide_gengrob <- function(...) UseMethod("guide_gengrob")
+#' @export
+#' @rdname guide-exts
+guide_geom <- function(guide, layers, default_mapping) UseMethod("guide_geom")
+
+#' @export
+#' @rdname guide-exts
+guide_gengrob <- function(guide, theme) UseMethod("guide_gengrob")
+
+
+# Helpers -----------------------------------------------------------------
+
+matched_aes <- function(layer, guide, defaults) {
+  all <- names(c(layer$mapping, if (layer$inherit.aes) defaults, layer$stat$default_aes))
+  geom <- c(layer$geom$required_aes, names(layer$geom$default_aes))
+  matched <- intersect(intersect(all, geom), names(guide$key))
+  matched <- setdiff(matched, names(layer$geom_params))
+  setdiff(matched, names(layer$aes_params))
+}
