@@ -1,16 +1,16 @@
 #' Position scales for continuous data (x & y)
 #'
-#' `scale_x_continuous` and `scale_y_continuous` are the default
+#' `scale_x_continuous()` and `scale_y_continuous()` are the default
 #' scales for continuous x and y aesthetics. There are three variants
 #' that set the `trans` argument for commonly used transformations:
-#' `scale_*_log10`, `scale_*_sqrt` and `scale_*_reverse`.
+#' `scale_*_log10()`, `scale_*_sqrt()` and `scale_*_reverse()`.
 #'
 #' For simple manipulation of labels and limits, you may wish to use
 #' [labs()] and [lims()] instead.
 #'
 #' @inheritParams continuous_scale
 #' @family position scales
-#' @param ... Other arguments passed on to `scale_(x|y)_continuous`
+#' @param ... Other arguments passed on to `scale_(x|y)_continuous()`
 #' @examples
 #' p1 <- ggplot(mpg, aes(displ, hwy)) +
 #'   geom_point()
@@ -36,7 +36,7 @@
 #' #  * choose where the ticks appear
 #' p1 + scale_x_continuous(breaks = c(2, 4, 6))
 #'
-#' #  * add what labels they have
+#' #  * choose your own labels
 #' p1 + scale_x_continuous(
 #'   breaks = c(2, 4, 6),
 #'   label = c("two", "four", "six")
@@ -63,6 +63,7 @@
 #' p1 + scale_y_continuous(trans = scales::reciprocal_trans())
 #'
 #' # You can also create your own. See ?scales::trans_new
+#'
 #' @name scale_continuous
 #' @aliases NULL
 NULL
@@ -85,12 +86,9 @@ scale_x_continuous <- function(name = waiver(), breaks = waiver(),
     expand = expand, oob = oob, na.value = na.value, trans = trans,
     guide = "none", position = position, super = ScaleContinuousPosition
   )
-  if (!is.waive(sec.axis)) {
-    if (is.formula(sec.axis)) sec.axis <- sec_axis(sec.axis)
-    if (!is.sec_axis(sec.axis)) stop("Secondary axes must be specified using 'sec_axis()'")
-    sc$secondary.axis <- sec.axis
-  }
-  sc
+
+  set_sec_axis(sec.axis, sc)
+
 }
 
 #' @rdname scale_continuous
@@ -107,12 +105,8 @@ scale_y_continuous <- function(name = waiver(), breaks = waiver(),
     expand = expand, oob = oob, na.value = na.value, trans = trans,
     guide = "none", position = position, super = ScaleContinuousPosition
   )
-  if (!is.waive(sec.axis)) {
-    if (is.formula(sec.axis)) sec.axis <- sec_axis(sec.axis)
-    if (!is.sec_axis(sec.axis)) stop("Secondary axes must be specified using 'sec_axis()'")
-    sc$secondary.axis <- sec.axis
-  }
-  sc
+
+  set_sec_axis(sec.axis, sc)
 }
 
 
