@@ -14,7 +14,7 @@
 #'   \item{n}{number of points}
 #'   \item{width}{width of violin bounding box}
 #' }
-#' @seealso \code{\link{geom_violin}} for examples, and \code{\link{stat_density}}
+#' @seealso [geom_violin()] for examples, and [stat_density()]
 #'   for examples with data along the x axis.
 #' @export
 #' @rdname geom_violin
@@ -63,13 +63,10 @@ StatYdensity <- ggproto("StatYdensity", Stat,
   compute_group = function(data, scales, width = NULL, bw = "nrd0", adjust = 1,
                        kernel = "gaussian", trim = TRUE, na.rm = FALSE) {
     if (nrow(data) < 3) return(data.frame())
-
-    if (trim) {
-      range <- range(data$y, na.rm = TRUE)
-    } else {
-      range <- scales$y$dimension()
-    }
-    dens <- compute_density(data$y, data$w, from = range[1], to = range[2],
+    range <- range(data$y, na.rm = TRUE)
+    modifier <- if (trim) 0 else 3
+    bw <- calc_bw(data$y, bw)
+    dens <- compute_density(data$y, data$w, from = range[1] - modifier*bw, to = range[2] + modifier*bw,
       bw = bw, adjust = adjust, kernel = kernel)
 
     dens$y <- dens$x
@@ -107,3 +104,22 @@ StatYdensity <- ggproto("StatYdensity", Stat,
   }
 
 )
+
+calc_bw <- function(x, bw) {
+  if (is.character(bw)) {
+    if (length(x) < 2)
+      stop("need at least 2 points to select a bandwidth automatically", call. = FALSE)
+    bw <- switch(
+      tolower(bw),
+      nrd0 = stats::bw.nrd0(x),
+      nrd = stats::bw.nrd(x),
+      ucv = stats::bw.ucv(x),
+      bcv = stats::bw.bcv(x),
+      sj = ,
+      `sj-ste` = stats::bw.SJ(x, method = "ste"),
+      `sj-dpi` = stats::bw.SJ(x, method = "dpi"),
+      stop("unknown bandwidth rule")
+    )
+  }
+  bw
+}
